@@ -33,7 +33,7 @@ THE SOFTWARE.
 #include "OgreResource.h"
 #include "OgreGpuProgramParams.h"
 #include "OgreHeaderPrefix.h"
-#include "OgreVector3.h"
+#include "OgreVector.h"
 #include "OgreSharedPtr.h"
 
 namespace Ogre {
@@ -135,32 +135,32 @@ namespace Ogre {
     static CmdManualNamedConstsFile msManNamedConstsFileCmd;
     static CmdAdjacency msAdjacencyCmd;
     static CmdComputeGroupDims msComputeGroupDimsCmd;
-    /// The type of the program
-    GpuProgramType mType;
     /// The name of the file to load source from (may be blank)
     String mFilename;
     /// The assembler source of the program (may be blank until file loaded)
     String mSource;
-    /// Whether we need to load source from file or not
-    bool mLoadFromFile;
     /// Syntax code e.g. arbvp1, vs_2_0 etc
     String mSyntaxCode;
+    /// The type of the program
+    GpuProgramType mType;
+    /// Whether we need to load source from file or not
+    bool mLoadFromFile;
     /// Does this (vertex) program include skeletal animation?
     bool mSkeletalAnimation;
     /// Does this (vertex) program include morph animation?
     bool mMorphAnimation;
-    /// Does this (vertex) program include pose animation (count of number of poses supported)
-    ushort mPoseAnimation;
     /// Does this (vertex) program require support for vertex texture fetch?
     bool mVertexTextureFetch;
     /// Does this (geometry) program require adjacency information?
     bool mNeedsAdjacencyInfo;
+    /// Did we encounter a compilation error?
+    bool mCompileError;
+    /// Does this (vertex) program include pose animation (count of number of poses supported)
+    ushort mPoseAnimation;
     /// The number of process groups dispatched by this (compute) program.
     Vector3 mComputeGroupDimensions;
     /// The default parameters for use with this object
     GpuProgramParametersSharedPtr mDefaultParams;
-    /// Did we encounter a compilation error?
-    bool mCompileError;
     /** Record of logical to physical buffer maps. Mandatory for low-level
         programs or high-level programs which set their params the same way.
         This is a shared pointer because if the program is recompiled and the parameters
@@ -190,15 +190,21 @@ namespace Ogre {
         @par
         The subclass must have called it's own createParamDictionary before calling this method.
     */
-    void setupBaseParamDictionary(void);
+    virtual void setupBaseParamDictionary(void);
 
     /** Internal method returns whether required capabilities for this program is supported.
      */
     bool isRequiredCapabilitiesSupported(void) const;
 
-    /// @copydoc Resource::loadImpl
+    // catches errors during prepare
+    void safePrepare();
+
+    void prepareImpl();
+
     void loadImpl(void);
 
+    void postLoadImpl();
+
     /// Create the internal params logical & named mapping structures
     void createParameterMappingStructures(bool recreateIfExists = true) const;
     /// Create the internal params logical mapping structures
@@ -324,9 +330,9 @@ namespace Ogre {
     */
     virtual bool isVertexTextureFetchRequired(void) const { return mVertexTextureFetch; }
 
-    /// @deprecated
-    virtual void setAdjacencyInfoRequired(bool r) { mNeedsAdjacencyInfo = r; }
-    /// @deprecated
+    /// @deprecated use OT_DETAIL_ADJACENCY_BIT
+    OGRE_DEPRECATED virtual void setAdjacencyInfoRequired(bool r) { mNeedsAdjacencyInfo = r; }
+    /// @deprecated use OT_DETAIL_ADJACENCY_BIT
     virtual bool isAdjacencyInfoRequired(void) const { return mNeedsAdjacencyInfo; }
     /** Sets the number of process groups dispatched by this compute
         program.
@@ -347,7 +353,7 @@ namespace Ogre {
         the default parameters; thus users of the program need only change the parameters
         which are unique to their own usage of the program.
     */
-    virtual GpuProgramParametersSharedPtr getDefaultParameters(void);
+    virtual const GpuProgramParametersPtr& getDefaultParameters(void);
 
     /** Returns true if default parameters have been set up.
      */
