@@ -57,14 +57,40 @@ namespace Ogre {
         IS_UNKNOWN
     };
 
-    /** Class defining a single pass of a Technique (of a Material), i.e.
-        a single rendering call.
-        @remarks
+    /** Class defining a single pass of a Technique (of a Material): a single rendering call.
+
+        If a pass does not explicitly use a vertex or fragment shader, %Ogre will calculate
+        lighting based on the [Direct3D Light Model](https://docs.microsoft.com/en-us/windows/win32/direct3d9/mathematics-of-lighting) as:
+
+        If at least one shader is used, the pass is considered *programmable* and the lighting is
+        up to the shader.
+
         Rendering can be repeated with many passes for more complex effects.
-        Each pass is either a fixed-function pass (meaning it does not use
-        a vertex or fragment program) or a programmable pass (meaning it does
-        use either a vertex and fragment program, or both).
-        @par
+
+        @copydetails setLightingEnabled
+
+        @par Lighting disabled
+
+        $$ passBase = C $$
+
+        where \f$C = (1, 1, 1)\f$ or a tracked vertex attribute if #TVC_DIFFUSE is set.
+
+        @par Lighting enabled
+
+        \f[ passBase = G_a \cdot C_a + \sum^N_i ( C_d \cdot L^{(i)}_d +  C_s \cdot L^{(i)}_s ) + C_e \f]
+
+        where
+        - \f$G_a\f$ is the ambient colour defined by the SceneManager
+        - \f$C_a\f$ is the pass ambient colour
+        - \f$C_e\f$ is the pass self-illumination colour or a tracked vertex attribute
+        - \f$N\f$ is the number of lights considered during light iteration
+        - \f$C_d\f$ is the pass diffuse colour or a tracked vertex attribute
+        - \f$C_s\f$ is the pass specular colour or a tracked vertex attribute
+        - \f$L_d^{(i)}\f$ is the (attenuated) diffuse colour of the i-th Light
+        - \f$L_s^{(i)}\f$ is the (attenuated) specular colour of the i-th Light
+
+        @par Programmable passes
+
         Programmable passes are complex to define, because they require custom
         programs and you have to set all constant inputs to the programs (like
         the position of lights, any base material colours you wish to use etc), but
@@ -248,35 +274,6 @@ namespace Ogre {
         /// Operator = overload
         Pass& operator=(const Pass& oth);
 
-        /// Returns true if this pass is programmable i.e. includes either a vertex or fragment program.
-        bool isProgrammable(void) const
-        {
-            for (const auto& u : mProgramUsage)
-                if (u) return true;
-            return false;
-        }
-
-        /// Returns true if this pass uses a programmable vertex pipeline
-        bool hasVertexProgram(void) const { return hasGpuProgram(GPT_VERTEX_PROGRAM); }
-        /// Returns true if this pass uses a programmable fragment pipeline
-        bool hasFragmentProgram(void) const { return hasGpuProgram(GPT_FRAGMENT_PROGRAM); }
-        /// Returns true if this pass uses a programmable geometry pipeline
-        bool hasGeometryProgram(void) const { return hasGpuProgram(GPT_GEOMETRY_PROGRAM); }
-        /// Returns true if this pass uses a programmable tessellation control pipeline
-        bool hasTessellationHullProgram(void) const { return hasGpuProgram(GPT_HULL_PROGRAM); }
-        /// Returns true if this pass uses a programmable tessellation control pipeline
-        bool hasTessellationDomainProgram(void) const { return hasGpuProgram(GPT_DOMAIN_PROGRAM); }
-        /// Returns true if this pass uses a programmable compute pipeline
-        bool hasComputeProgram(void) const { return hasGpuProgram(GPT_COMPUTE_PROGRAM); }
-        /// Returns true if this pass uses a shadow caster vertex program
-        bool hasShadowCasterVertexProgram(void) const { return mShadowCasterVertexProgramUsage != NULL; }
-        /// Returns true if this pass uses a shadow caster fragment program
-        bool hasShadowCasterFragmentProgram(void) const { return mShadowCasterFragmentProgramUsage != NULL; }
-        /// Returns true if this pass uses a shadow receiver vertex program
-        bool hasShadowReceiverVertexProgram(void) const { return mShadowReceiverVertexProgramUsage != NULL; }
-        /// Returns true if this pass uses a shadow receiver fragment program
-        bool hasShadowReceiverFragmentProgram(void) const { return mShadowReceiverFragmentProgramUsage != NULL; }
-
         size_t calculateSize(void) const;
 
         /// Gets the index of this Pass in the parent Technique
@@ -290,6 +287,8 @@ namespace Ogre {
         /// Get the name of the pass
         const String& getName(void) const { return mName; }
 
+        /// @name Surface properties
+        /// @{
         /** Sets the ambient colour reflectance properties of this pass.
 
         This property determines how much ambient light (directionless global light) is
@@ -391,6 +390,55 @@ namespace Ogre {
          */
         void setVertexColourTracking(TrackVertexColourType tracking);
 
+        /** Gets the ambient colour reflectance of the pass.
+         */
+        const ColourValue& getAmbient(void) const;
+
+        /** Gets the diffuse colour reflectance of the pass.
+         */
+        const ColourValue& getDiffuse(void) const;
+
+        /** Gets the specular colour reflectance of the pass.
+         */
+        const ColourValue& getSpecular(void) const;
+
+        /** Gets the self illumination colour of the pass.
+         */
+        const ColourValue& getSelfIllumination(void) const;
+
+        /** Gets the self illumination colour of the pass.
+            @see
+            getSelfIllumination
+        */
+        const ColourValue& getEmissive(void) const
+        {
+            return getSelfIllumination();
+        }
+
+        /** Gets the 'shininess' property of the pass (affects specular highlights).
+         */
+        Real getShininess(void) const;
+
+        /** Gets which material properties follow the vertex colour
+         */
+        TrackVertexColourType getVertexColourTracking(void) const;
+
+        /** Sets whether or not dynamic lighting is enabled.
+
+            Turning dynamic lighting off makes any ambient, diffuse, specular, emissive and shading
+            properties for this pass redundant.
+            If lighting is turned off, all objects rendered using the pass will be fully lit.
+            When lighting is turned on, objects are lit according
+            to their vertex normals for diffuse and specular light, and globally for ambient and
+            emissive.
+        */
+        void setLightingEnabled(bool enabled);
+
+        /** Returns whether or not dynamic lighting is enabled.
+         */
+        bool getLightingEnabled(void) const;
+        /// @}
+
         /**
          * set the line width for this pass
          *
@@ -400,6 +448,8 @@ namespace Ogre {
         void setLineWidth(float width) { mLineWidth = width; }
         float getLineWidth() const { return mLineWidth; }
 
+        /// @name Point Sprites
+        /// @{
         /** Gets the point size of the pass.
             @remarks
             This property determines what point size is used to render a point
@@ -483,40 +533,12 @@ namespace Ogre {
             @remarks 0 indicates the max size supported by the card.
         */
         Real getPointMaxSize(void) const;
+        /// @}
 
-        /** Gets the ambient colour reflectance of the pass.
-         */
-        const ColourValue& getAmbient(void) const;
-
-        /** Gets the diffuse colour reflectance of the pass.
-         */
-        const ColourValue& getDiffuse(void) const;
-
-        /** Gets the specular colour reflectance of the pass.
-         */
-        const ColourValue& getSpecular(void) const;
-
-        /** Gets the self illumination colour of the pass.
-         */
-        const ColourValue& getSelfIllumination(void) const;
-
-        /** Gets the self illumination colour of the pass.
-            @see
-            getSelfIllumination
-        */
-        const ColourValue& getEmissive(void) const
-        {
-            return getSelfIllumination();
-        }
-
-        /** Gets the 'shininess' property of the pass (affects specular highlights).
-         */
-        Real getShininess(void) const;
-
-        /** Gets which material properties follow the vertex colour
-         */
-        TrackVertexColourType getVertexColourTracking(void) const;
-
+        typedef VectorIterator<TextureUnitStates> TextureUnitStateIterator;
+        typedef ConstVectorIterator<TextureUnitStates> ConstTextureUnitStateIterator;
+        /// @name Texture Units
+        /// @{
         /** Inserts a new TextureUnitState object into the Pass.
             @remarks
             This unit is is added on top of all previous units.
@@ -556,12 +578,10 @@ namespace Ogre {
         */
         unsigned short getTextureUnitStateIndex(const TextureUnitState* state) const;
 
-        typedef VectorIterator<TextureUnitStates> TextureUnitStateIterator;
         /** Get an iterator over the TextureUnitStates contained in this Pass.
          * @deprecated use getTextureUnitStates() */
         OGRE_DEPRECATED TextureUnitStateIterator getTextureUnitStateIterator(void);
 
-        typedef ConstVectorIterator<TextureUnitStates> ConstTextureUnitStateIterator;
         /** Get an iterator over the TextureUnitStates contained in this Pass.
          * @deprecated use getTextureUnitStates() */
         OGRE_DEPRECATED ConstTextureUnitStateIterator getTextureUnitStateIterator(void) const;
@@ -587,6 +607,40 @@ namespace Ogre {
             return static_cast<unsigned short>(mTextureUnitStates.size());
         }
 
+        /// @deprecated use getTextureUnitState("alias")->setTextureName("texture.png") instead
+        OGRE_DEPRECATED bool applyTextureAliases(const AliasTextureNamePairList& aliasList, const bool apply = true) const;
+
+        /** Gets the 'nth' texture which references the given content type.
+            @remarks
+            If the 'nth' texture unit which references the content type doesn't
+            exist, then this method returns an arbitrary high-value outside the
+            valid range to index texture units.
+        */
+        unsigned short _getTextureUnitWithContentTypeIndex(
+            TextureUnitState::ContentType contentType, unsigned short index) const;
+
+        /** Set texture filtering for every texture unit
+            @note
+            This property actually exists on the TextureUnitState class
+            For simplicity, this method allows you to set these properties for
+            every current TeextureUnitState, If you need more precision, retrieve the
+            TextureUnitState instance and set the property there.
+            @see TextureUnitState::setTextureFiltering
+        */
+        void setTextureFiltering(TextureFilterOptions filterType);
+        /** Sets the anisotropy level to be used for all textures.
+            @note
+            This property has been moved to the TextureUnitState class, which is accessible via the
+            Technique and Pass. For simplicity, this method allows you to set these properties for
+            every current TeextureUnitState, If you need more precision, retrieve the Technique,
+            Pass and TextureUnitState instances and set the property there.
+            @see TextureUnitState::setTextureAnisotropy
+        */
+        void setTextureAnisotropy(unsigned int maxAniso);
+        /// @}
+
+        /// @name Scene Blending
+        /// @{
         /** Sets the kind of blending this pass has with the existing contents of the scene.
 
             Whereas the texture blending operations seen in the TextureUnitState class are concerned with
@@ -689,9 +743,33 @@ namespace Ogre {
         /** Returns the current alpha blending operation */
         SceneBlendOperation getSceneBlendingOperationAlpha() const;
 
+        /** Sets whether or not colour buffer writing is enabled for this %Pass.
+
+            If colour writing is off no visible pixels are written to the screen during this pass.
+            You might think this is useless, but if you render with colour writing off, and with very
+            minimal other settings, you can use this pass to initialise the depth buffer before
+            subsequently rendering other passes which fill in the colour data. This can give you
+            significant performance boosts on some newer cards, especially when using complex
+            fragment programs, because if the depth check fails then the fragment program is never
+            run.
+        */
+        void setColourWriteEnabled(bool enabled);
+        /** Determines if colour buffer writing is enabled for this pass i.e. when at least one
+            colour channel is enabled for writing.
+         */
+        bool getColourWriteEnabled(void) const;
+
+        /// Sets which colour buffer channels are enabled for writing for this Pass
+        void setColourWriteEnabled(bool red, bool green, bool blue, bool alpha);
+        /// Determines which colour buffer channels are enabled for writing for this pass.
+        void getColourWriteEnabled(bool& red, bool& green, bool& blue, bool& alpha) const;
+        /// @}
+
         /** Returns true if this pass has some element of transparency. */
         bool isTransparent(void) const;
 
+        /// @name Depth Testing
+        /// @{
         /** Sets whether or not this pass renders with depth-buffer checking on or not.
 
             If depth-buffer checking is on, whenever a pixel is about to be written to the frame buffer
@@ -737,26 +815,46 @@ namespace Ogre {
         */
         CompareFunction getDepthFunction(void) const;
 
-        /** Sets whether or not colour buffer writing is enabled for this %Pass.
+        /** Sets the depth bias to be used for this material.
 
-            If colour writing is off no visible pixels are written to the screen during this pass.
-            You might think this is useless, but if you render with colour writing off, and with very
-            minimal other settings, you can use this pass to initialise the depth buffer before
-            subsequently rendering other passes which fill in the colour data. This can give you
-            significant performance boosts on some newer cards, especially when using complex
-            fragment programs, because if the depth check fails then the fragment program is never
-            run.
+            When polygons are coplanar, you can get problems with 'depth fighting' where
+            the pixels from the two polys compete for the same screen pixel. This is particularly
+            a problem for decals (polys attached to another surface to represent details such as
+            bulletholes etc.).
+
+            A way to combat this problem is to use a depth bias to adjust the depth buffer value
+            used for the decal such that it is slightly higher than the true value, ensuring that
+            the decal appears on top. There are two aspects to the biasing, a constant
+            bias value and a slope-relative biasing value, which varies according to the
+            maximum depth slope relative to the camera, ie:
+
+            $$finalBias = maxSlope * slopeScaleBias + constantBias$$
+
+            Slope scale biasing is relative to the angle of the polygon to the camera, which makes
+            for a more appropriate bias value, but this is ignored on some older hardware. Constant
+            biasing is expressed as a factor of the minimum depth value, so a value of 1 will nudge
+            the depth by one ’notch’ if you will.
+            @param constantBias The constant bias value
+            @param slopeScaleBias The slope-relative bias value
         */
-        void setColourWriteEnabled(bool enabled);
-        /** Determines if colour buffer writing is enabled for this pass i.e. when at least one
-            colour channel is enabled for writing.
-         */
-        bool getColourWriteEnabled(void) const;
+        void setDepthBias(float constantBias, float slopeScaleBias = 0.0f);
 
-        /// Sets which colour buffer channels are enabled for writing for this Pass
-        void setColourWriteEnabled(bool red, bool green, bool blue, bool alpha);
-        /// Determines which colour buffer channels are enabled for writing for this pass.
-        void getColourWriteEnabled(bool& red, bool& green, bool& blue, bool& alpha) const;
+        /** Retrieves the const depth bias value as set by setDepthBias. */
+        float getDepthBiasConstant(void) const;
+        /** Retrieves the slope-scale depth bias value as set by setDepthBias. */
+        float getDepthBiasSlopeScale(void) const;
+        /** Sets a factor which derives an additional depth bias from the number
+            of times a pass is iterated.
+            @remarks
+            The Final depth bias will be the constant depth bias as set through
+            setDepthBias, plus this value times the iteration number.
+        */
+        void setIterationDepthBias(float biasPerIteration);
+        /** Gets a factor which derives an additional depth bias from the number
+            of times a pass is iterated.
+        */
+        float getIterationDepthBias() const;
+        /// @}
 
         /** Sets the culling mode for this pass based on the 'vertex winding'.
             A typical way for the rendering engine to cull triangles is based on the 'vertex winding' of
@@ -801,52 +899,6 @@ namespace Ogre {
         */
         ManualCullingMode getManualCullingMode(void) const;
 
-        /** Sets whether or not dynamic lighting is enabled.
-
-            Turning dynamic lighting off makes any ambient, diffuse, specular, emissive and shading
-            properties for this pass redundant. 
-            If lighting is turned off, all objects rendered using the pass will be fully lit.
-            When lighting is turned on, objects are lit according
-            to their vertex normals for diffuse and specular light, and globally for ambient and
-            emissive.
-        */
-        void setLightingEnabled(bool enabled);
-
-        /** Returns whether or not dynamic lighting is enabled.
-         */
-        bool getLightingEnabled(void) const;
-
-        /** Sets the maximum number of lights to be used by this pass.
-            @remarks
-            During rendering, if lighting is enabled (or if the pass uses an automatic
-            program parameter based on a light) the engine will request the nearest lights
-            to the object being rendered in order to work out which ones to use. This
-            parameter sets the limit on the number of lights which should apply to objects
-            rendered with this pass.
-        */
-        void setMaxSimultaneousLights(unsigned short maxLights);
-        /** Gets the maximum number of lights to be used by this pass. */
-        unsigned short getMaxSimultaneousLights(void) const;
-
-        /** Sets the light index that this pass will start at in the light list.
-
-            Normally the lights passed to a pass will start from the beginning
-            of the light list for this object. This option allows you to make this
-            pass start from a higher light index, for example if one of your earlier
-            passes could deal with lights 0-3, and this pass dealt with lights 4+.
-            This option also has an interaction with pass iteration, in that
-            if you choose to iterate this pass per light too, the iteration will
-            only begin from light 4.
-        */
-        void setStartLight(unsigned short startLight);
-        /** Gets the light index that this pass will start at in the light list. */
-        unsigned short getStartLight(void) const;
-
-        /** Sets the light mask which can be matched to specific light flags to be handled by this pass */
-        void setLightMask(uint32 mask);
-        /** Gets the light mask controlling which lights are used for this pass */
-        uint32 getLightMask() const;
-
         /** Sets the type of light shading required
 
             When dynamic lighting is turned on, the effect is to generate colour values at each
@@ -887,6 +939,9 @@ namespace Ogre {
         {
             return mPolygonModeOverrideable;
         }
+
+        /// @name Fogging
+        /// @{
         /** Sets the fogging mode applied to this pass.
             @remarks
             Fogging is an effect that is applied as polys are rendered. Sometimes, you want
@@ -953,47 +1008,10 @@ namespace Ogre {
             Only valid if getFogOverride is true.
         */
         Real getFogDensity(void) const;
+        /// @}
 
-        /** Sets the depth bias to be used for this material.
-
-            When polygons are coplanar, you can get problems with 'depth fighting' where
-            the pixels from the two polys compete for the same screen pixel. This is particularly
-            a problem for decals (polys attached to another surface to represent details such as
-            bulletholes etc.).
-
-            A way to combat this problem is to use a depth bias to adjust the depth buffer value
-            used for the decal such that it is slightly higher than the true value, ensuring that
-            the decal appears on top. There are two aspects to the biasing, a constant
-            bias value and a slope-relative biasing value, which varies according to the
-            maximum depth slope relative to the camera, ie:
-
-            $$finalBias = maxSlope * slopeScaleBias + constantBias$$
-
-            Slope scale biasing is relative to the angle of the polygon to the camera, which makes
-            for a more appropriate bias value, but this is ignored on some older hardware. Constant
-            biasing is expressed as a factor of the minimum depth value, so a value of 1 will nudge
-            the depth by one ’notch’ if you will.
-            @param constantBias The constant bias value
-            @param slopeScaleBias The slope-relative bias value
-        */
-        void setDepthBias(float constantBias, float slopeScaleBias = 0.0f);
-
-        /** Retrieves the const depth bias value as set by setDepthBias. */
-        float getDepthBiasConstant(void) const;
-        /** Retrieves the slope-scale depth bias value as set by setDepthBias. */
-        float getDepthBiasSlopeScale(void) const;
-        /** Sets a factor which derives an additional depth bias from the number
-            of times a pass is iterated.
-            @remarks
-            The Final depth bias will be the constant depth bias as set through
-            setDepthBias, plus this value times the iteration number.
-        */
-        void setIterationDepthBias(float biasPerIteration);
-        /** Gets a factor which derives an additional depth bias from the number
-            of times a pass is iterated.
-        */
-        float getIterationDepthBias() const;
-
+        /// @name Alpha Rejection
+        /// @{
         /** Sets the way the pass will have use alpha to totally reject pixels from the pipeline.
             @remarks
             The default is CMPF_ALWAYS_PASS i.e. alpha is not used to reject pixels.
@@ -1035,6 +1053,7 @@ namespace Ogre {
         /** Gets whether to use alpha to coverage (A2C) when blending alpha rejected values.
          */
         bool isAlphaToCoverageEnabled() const { return mAlphaToCoverageEnabled; }
+        /// @}
 
         /** Sets whether or not transparent sorting is enabled.
             @param enabled
@@ -1069,6 +1088,39 @@ namespace Ogre {
          */
         bool getTransparentSortingForced(void) const;
 
+        /// @name Light Iteration
+        /// @{
+        /** Sets the maximum number of lights to be used by this pass.
+            @remarks
+            During rendering, if lighting is enabled (or if the pass uses an automatic
+            program parameter based on a light) the engine will request the nearest lights
+            to the object being rendered in order to work out which ones to use. This
+            parameter sets the limit on the number of lights which should apply to objects
+            rendered with this pass.
+        */
+        void setMaxSimultaneousLights(unsigned short maxLights);
+        /** Gets the maximum number of lights to be used by this pass. */
+        unsigned short getMaxSimultaneousLights(void) const;
+
+        /** Sets the light index that this pass will start at in the light list.
+
+            Normally the lights passed to a pass will start from the beginning
+            of the light list for this object. This option allows you to make this
+            pass start from a higher light index, for example if one of your earlier
+            passes could deal with lights 0-3, and this pass dealt with lights 4+.
+            This option also has an interaction with pass iteration, in that
+            if you choose to iterate this pass per light too, the iteration will
+            only begin from light 4.
+        */
+        void setStartLight(unsigned short startLight);
+        /** Gets the light index that this pass will start at in the light list. */
+        unsigned short getStartLight(void) const;
+
+        /** Sets the light mask which can be matched to specific light flags to be handled by this pass */
+        void setLightMask(uint32 mask);
+        /** Gets the light mask controlling which lights are used for this pass */
+        uint32 getLightMask() const;
+
         /** Sets whether or not this pass should iterate per light or number of
             lights which can affect the object being rendered.
             @remarks
@@ -1136,6 +1188,7 @@ namespace Ogre {
             iteration.
         */
         unsigned short getLightCountPerIteration(void) const;
+        /// @}
 
         /// Gets the parent Technique
         Technique* getParent(void) const { return mParent; }
@@ -1143,6 +1196,36 @@ namespace Ogre {
         /// Gets the resource group of the ultimate parent Material
         const String& getResourceGroup(void) const;
 
+        /// @name Gpu Programs
+        /// @{
+
+        /// Returns true if this pass is programmable i.e. includes either a vertex or fragment program.
+        bool isProgrammable(void) const
+        {
+            for (const auto& u : mProgramUsage)
+                if (u) return true;
+            return false;
+        }
+        /// Returns true if this pass uses a programmable vertex pipeline
+        bool hasVertexProgram(void) const { return hasGpuProgram(GPT_VERTEX_PROGRAM); }
+        /// Returns true if this pass uses a programmable fragment pipeline
+        bool hasFragmentProgram(void) const { return hasGpuProgram(GPT_FRAGMENT_PROGRAM); }
+        /// Returns true if this pass uses a programmable geometry pipeline
+        bool hasGeometryProgram(void) const { return hasGpuProgram(GPT_GEOMETRY_PROGRAM); }
+        /// Returns true if this pass uses a programmable tessellation control pipeline
+        bool hasTessellationHullProgram(void) const { return hasGpuProgram(GPT_HULL_PROGRAM); }
+        /// Returns true if this pass uses a programmable tessellation control pipeline
+        bool hasTessellationDomainProgram(void) const { return hasGpuProgram(GPT_DOMAIN_PROGRAM); }
+        /// Returns true if this pass uses a programmable compute pipeline
+        bool hasComputeProgram(void) const { return hasGpuProgram(GPT_COMPUTE_PROGRAM); }
+        /// Returns true if this pass uses a shadow caster vertex program
+        bool hasShadowCasterVertexProgram(void) const { return mShadowCasterVertexProgramUsage != NULL; }
+        /// Returns true if this pass uses a shadow caster fragment program
+        bool hasShadowCasterFragmentProgram(void) const { return mShadowCasterFragmentProgramUsage != NULL; }
+        /// Returns true if this pass uses a shadow receiver vertex program
+        bool hasShadowReceiverVertexProgram(void) const { return mShadowReceiverVertexProgramUsage != NULL; }
+        /// Returns true if this pass uses a shadow receiver fragment program
+        bool hasShadowReceiverFragmentProgram(void) const { return mShadowReceiverFragmentProgramUsage != NULL; }
         /// Gets the Gpu program used by this pass, only available after _load()
         const GpuProgramPtr& getGpuProgram(GpuProgramType programType) const;
         /// @overload
@@ -1161,9 +1244,9 @@ namespace Ogre {
         bool hasGpuProgram(GpuProgramType programType) const;
 
         /// @deprecated use Ogre::Technique::setShadowCasterMaterial
-        void setShadowCasterVertexProgram(const String& name);
+        OGRE_DEPRECATED void setShadowCasterVertexProgram(const String& name);
         /// @deprecated use Ogre::Technique::setShadowCasterMaterial
-        void setShadowCasterVertexProgramParameters(GpuProgramParametersSharedPtr params);
+        OGRE_DEPRECATED void setShadowCasterVertexProgramParameters(GpuProgramParametersSharedPtr params);
         /// @deprecated use Ogre::Technique::getShadowCasterMaterial
         const String& getShadowCasterVertexProgramName(void) const;
         /// @deprecated use Ogre::Technique::getShadowCasterMaterial
@@ -1171,9 +1254,9 @@ namespace Ogre {
         /// @deprecated use Ogre::Technique::getShadowCasterMaterial
         const GpuProgramPtr& getShadowCasterVertexProgram(void) const;
         /// @deprecated use Ogre::Technique::setShadowCasterMaterial
-        void setShadowCasterFragmentProgram(const String& name);
+        OGRE_DEPRECATED void setShadowCasterFragmentProgram(const String& name);
         /// @deprecated use Ogre::Technique::setShadowCasterMaterial
-        void setShadowCasterFragmentProgramParameters(GpuProgramParametersSharedPtr params);
+        OGRE_DEPRECATED void setShadowCasterFragmentProgramParameters(GpuProgramParametersSharedPtr params);
         /// @deprecated use Ogre::Technique::getShadowCasterMaterial
         const String& getShadowCasterFragmentProgramName(void) const;
         /// @deprecated use Ogre::Technique::getShadowCasterMaterial
@@ -1181,83 +1264,26 @@ namespace Ogre {
         /// @deprecated use Ogre::Technique::getShadowCasterMaterial
         const GpuProgramPtr& getShadowCasterFragmentProgram(void) const;
 
-        /** Sets the details of the vertex program to use when rendering as a
-            shadow receiver.
-            @remarks
-            Texture-based shadows require that the shadow receiver is rendered using
-            a projective texture. Whilst Ogre can arrange this for the fixed function
-            pipeline, passes which use vertex programs might need the vertex
-            programs still to run in order to preserve any deformation etc
-            that it does. So in this case, we need a vertex program which does the
-            appropriate vertex transformation, but generates projective texture
-            coordinates.
-            @par
-            Therefore, it is up to implementors of vertex programs to provide an
-            alternative vertex program which can be used to render the object
-            as a shadow receiver. Do all the same vertex transforms, but generate
-            <strong>2 sets</strong> of texture coordinates using the auto parameter
-            ACT_TEXTURE_VIEWPROJ_MATRIX, which Ogre will bind to the parameter name /
-            index you supply as the second parameter to this method. 2 texture
-            sets are needed because Ogre needs to use 2 texture units for some
-            shadow effects.
-            @note
-            This is only applicable to programmable passes.
-            @par
-            The default behaviour is for Ogre to switch to fixed-function
-            rendering if an explict vertex program alternative is not set.
-        */
-        void setShadowReceiverVertexProgram(const String& name);
-        /** Sets the vertex program parameters for rendering as a shadow receiver.
-            @remarks
-            Only applicable to programmable passes, and this particular call is
-            designed for low-level programs; use the named parameter methods
-            for setting high-level program parameters.
-        */
-        void setShadowReceiverVertexProgramParameters(GpuProgramParametersSharedPtr params);
+        /// @deprecated use Ogre::Technique::setShadowReceiverMaterial
+        OGRE_DEPRECATED void setShadowReceiverVertexProgram(const String& name);
+        /// @deprecated use Ogre::Technique::setShadowReceiverMaterial
+        OGRE_DEPRECATED void setShadowReceiverVertexProgramParameters(GpuProgramParametersSharedPtr params);
+        /// @deprecated use Ogre::Technique::setShadowReceiverMaterial
+        OGRE_DEPRECATED void setShadowReceiverFragmentProgram(const String& name);
+        /// @deprecated use Ogre::Technique::setShadowReceiverMaterial
+        OGRE_DEPRECATED void setShadowReceiverFragmentProgramParameters(GpuProgramParametersSharedPtr params);
 
-        /** This method allows you to specify a fragment program for use when
-            rendering a texture shadow receiver.
-            @remarks
-            Texture shadows are applied by rendering the receiver. Modulative texture
-            shadows are performed as a post-render darkening pass, and as such
-            fragment programs are generally not required per-object. Additive
-            texture shadows, however, are applied by accumulating light masked
-            out using a texture shadow (black & white by default, unless you
-            customise this using SceneManager::setCustomShadowCasterMaterial).
-            OGRE can do this for you for most materials, but if you use a custom
-            lighting program (e.g. per pixel lighting) then you'll need to provide
-            a custom version for receiving shadows. You don't need to provide
-            this for shadow casters if you don't use self-shadowing since they
-            will never be shadow receivers too.
-            @par
-            The shadow texture is always bound to texture unit 0 when rendering
-            texture shadow passes. Therefore your custom shadow receiver program
-            may well just need to shift it's texture unit usage up by one unit,
-            and take the shadow texture into account in its calculations.
-        */
-        void setShadowReceiverFragmentProgram(const String& name);
-        /** Sets the fragment program parameters for rendering as a shadow receiver.
-            @remarks
-            Only applicable to programmable passes, and this particular call is
-            designed for low-level programs; use the named parameter methods
-            for setting high-level program parameters.
-        */
-        void setShadowReceiverFragmentProgramParameters(GpuProgramParametersSharedPtr params);
-
-        /** Gets the name of the vertex program used by this pass when rendering shadow receivers. */
+        /// @deprecated use Ogre::Technique::getShadowReceiverMaterial
         const String& getShadowReceiverVertexProgramName(void) const;
-        /** Gets the vertex program parameters used by this pass when rendering shadow receivers. */
+        /// @deprecated use Ogre::Technique::getShadowReceiverMaterial
         GpuProgramParametersSharedPtr getShadowReceiverVertexProgramParameters(void) const;
-        /** Gets the vertex program used by this pass when rendering shadow receivers,
-            only available after _load(). */
+        /// @deprecated use Ogre::Technique::getShadowReceiverMaterial
         const GpuProgramPtr& getShadowReceiverVertexProgram(void) const;
-
-        /** Gets the name of the fragment program used by this pass when rendering shadow receivers. */
+        /// @deprecated use Ogre::Technique::getShadowReceiverMaterial
         const String& getShadowReceiverFragmentProgramName(void) const;
-        /** Gets the fragment program parameters used by this pass when rendering shadow receivers. */
+        /// @deprecated use Ogre::Technique::getShadowReceiverMaterial
         GpuProgramParametersSharedPtr getShadowReceiverFragmentProgramParameters(void) const;
-        /** Gets the fragment program used by this pass when rendering shadow receivers,
-            only available after _load(). */
+        /// @deprecated use Ogre::Technique::getShadowReceiverMaterial
         const GpuProgramPtr& getShadowReceiverFragmentProgram(void) const;
 
         /** Sets the details of the program to use.
@@ -1340,6 +1366,7 @@ namespace Ogre {
         GpuProgramParametersSharedPtr getTessellationDomainProgramParameters(void) const;
         /// @overload
         GpuProgramParametersSharedPtr getComputeProgramParameters(void) const;
+        /// @}
 
         /** Splits this Pass to one which can be handled in the number of
             texture units specified.
@@ -1393,33 +1420,6 @@ namespace Ogre {
         */
         void _updateAutoParams(const AutoParamDataSource* source, uint16 variabilityMask) const;
 
-        /** Gets the 'nth' texture which references the given content type.
-            @remarks
-            If the 'nth' texture unit which references the content type doesn't
-            exist, then this method returns an arbitrary high-value outside the
-            valid range to index texture units.
-        */
-        unsigned short _getTextureUnitWithContentTypeIndex(
-            TextureUnitState::ContentType contentType, unsigned short index) const;
-
-        /** Set texture filtering for every texture unit
-            @note
-            This property actually exists on the TextureUnitState class
-            For simplicity, this method allows you to set these properties for
-            every current TeextureUnitState, If you need more precision, retrieve the
-            TextureUnitState instance and set the property there.
-            @see TextureUnitState::setTextureFiltering
-        */
-        void setTextureFiltering(TextureFilterOptions filterType);
-        /** Sets the anisotropy level to be used for all textures.
-            @note
-            This property has been moved to the TextureUnitState class, which is accessible via the
-            Technique and Pass. For simplicity, this method allows you to set these properties for
-            every current TeextureUnitState, If you need more precision, retrieve the Technique,
-            Pass and TextureUnitState instances and set the property there.
-            @see TextureUnitState::setTextureAnisotropy
-        */
-        void setTextureAnisotropy(unsigned int maxAniso);
         /** If set to true, this forces normals to be normalised dynamically
             by the hardware for this pass.
 
@@ -1483,9 +1483,6 @@ namespace Ogre {
          */
         size_t getPassIterationCount(void) const { return mPassIterationCount; }
 
-        /// @deprecated use getTextureUnitState("alias")->setTextureName("texture.png") instead
-        OGRE_DEPRECATED bool applyTextureAliases(const AliasTextureNamePairList& aliasList, const bool apply = true) const;
-
         /** Sets whether or not this pass will be clipped by a scissor rectangle
             encompassing the lights that are being used in it.
 
