@@ -19,7 +19,9 @@ cmake .. \
       -DOGRE_INSTALL_PDB=FALSE \
       -DOGRE_RESOURCEMANAGER_STRICT=0 \
       -DOGRE_THREAD_SUPPORT=2 \
-      -DOGRE_THREAD_PROVIDER=1
+      -DOGRE_THREAD_PROVIDER=1 \
+      -DOGRE_BUILD_LIBS_AS_FRAMEWORKS=0 \
+      -DOGRE_ENABLE_PRECOMPILED_HEADERS=0
 
 make -j${CPU_COUNT}
 make install
